<p align="center">
    <img width="300" src="./assets/logo-dark-theme.png#gh-dark-mode-only"/>
    <img width="300" src="./assets/logo-light-theme.png#gh-light-mode-only"/>
</p>
<br>

[![Python](https://img.shields.io/badge/Python-3776AB?&logo=python&logoColor=white)](https://www.python.org/)
[![MQTT](https://img.shields.io/static/v1?message=MQTT&color=660066&logo=MQTT&logoColor=FFFFFF&label=)](https://mqtt.org/)
[![Docker](https://img.shields.io/badge/-Docker-2496ED?logo=docker&logoColor=white)](https://www.docker.com/)
[![ROS](https://img.shields.io/static/v1?message=ROS2&color=22314E&logo=ROS&logoColor=FFFFFF&label=)](https://docs.ros.org/en/humble/index.html)

[![License: Apache2.0](https://img.shields.io/badge/License-Apache2.0-yellow.svg)](https://www.apache.org/licenses/LICENSE-2.0.txt)

[![Twitter](https://img.shields.io/badge/Follow-Airbotics-1DA1F2?logo=twitter)](https://twitter.com/Airboticsio)


# The Airbotics Agent
This repository contains the source code for the [Airbotics](https://airbotics.io) agent. The agent is designed to run as a background service that is responsible for maintaining communications with:

1. The MQTT broker in the airbotics cloud.
2. ROS2 on the host machine.
3. The Docker Engine to on the host machine (optional).


## Documentation
Check the latest [documentation](https://docs.airbotics.io) to get started.

## License
This software is licensed under [Apache 2.0](./LICENSE)